@@ -7,6 +7,7 @@
 # pylint: disable=redefined-outer-name, logging-not-lazy, logging-format-interpolation
 
 import os
+from sys import stdout
 import logging
 
 from regapp_tools.parse_args import args
@@ -29,7 +30,7 @@ def main():
 
     external_id = external_id_from_subiss(sub_iss=args.sub_iss)
     username = get_username_from_external_id(external_id)
-    print (username)
+    stdout.write(username)
 
 if __name__ == '__main__':
     main()
